<?php

namespace Litecms\Icons\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Icons\Models\Icon;

class IconPolicy
{

    /**
     * Determine if the given user can view the icon.
     *
     * @param UserPolicy $user
     * @param Icon $icon
     *
     * @return bool
     */
    public function view(UserPolicy $user, Icon $icon)
    {
        if ($user->canDo('icons.icon.view') && $user->isAdmin()) {
            return true;
        }

        return $icon->user_id == user_id() && $icon->user_type == user_type();
    }

    /**
     * Determine if the given user can create a icon.
     *
     * @param UserPolicy $user
     * @param Icon $icon
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('icons.icon.create');
    }

    /**
     * Determine if the given user can update the given icon.
     *
     * @param UserPolicy $user
     * @param Icon $icon
     *
     * @return bool
     */
    public function update(UserPolicy $user, Icon $icon)
    {
        if ($user->canDo('icons.icon.edit') && $user->isAdmin()) {
            return true;
        }

        return $icon->user_id == user_id() && $icon->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given icon.
     *
     * @param UserPolicy $user
     * @param Icon $icon
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Icon $icon)
    {
        return $icon->user_id == user_id() && $icon->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given icon.
     *
     * @param UserPolicy $user
     * @param Icon $icon
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Icon $icon)
    {
        if ($user->canDo('icons.icon.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given icon.
     *
     * @param UserPolicy $user
     * @param Icon $icon
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Icon $icon)
    {
        if ($user->canDo('icons.icon.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
